@@ -1,7 +1,7 @@
 /*
- * have_stdvs - try <stdarg.h> to see if it really works with vsprintf()
+ * have_stdvs - try <stdarg.h> to see if it really works with vsnprintf()
  *
- * Copyright (C) 1999,2014  Landon Curt Noll
+ * Copyright (C) 1999,2014,2018  Landon Curt Noll
  *
  * Calc is open software; you can redistribute it and/or modify it under
  * the terms of the version 2.1 of the GNU Lesser General Public License
@@ -17,10 +17,6 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.4 $
- * @(#) $Id: have_stdvs.c,v 30.4 2014/08/24 21:57:31 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/have_stdvs.c,v $
- *
  * Under source code control:	1995/09/09 22:41:10
  * File existed as early as:	1995
  *
@@ -29,16 +25,16 @@
  */
 
 /*
- * On some systems that have both <stdarg.h> and <varargs.h>, vsprintf()
+ * On some systems that have both <stdarg.h> and <varargs.h>, vsnprintf()
  * does not work well under one type of include file.
  *
  * Some systems (such as UMIPS) have bugs in the <stdarg.h> implementation
- * that show up in vsprintf(), so we may have to try to use sprintf()
- * as if it were vsprintf() and hope for the best.
+ * that show up in vsnprintf(), so we may have to try to use snprintf()
+ * as if it were vsnprintf() and hope for the best.
  *
- * This program will output #defines and exits 0 if vsprintf() (or sprintf())
- * produces the results that we expect.	 This program exits 1 if vsprintf()
- * (or sprintf()) produces unexpected results while using the <stdarg.h>
+ * This program will output #defines and exits 0 if vsnprintf() (or snprintf())
+ * produces the results that we expect.	 This program exits 1 if vsnprintf()
+ * (or snprintf()) produces unexpected results while using the <stdarg.h>
  * include file.
  */
 
@@ -61,39 +57,24 @@
 # include <stdlib.h>
 #endif
 
-#undef VSPRINTF_SIZE_T
+#undef VSNPRINTF_SIZE_T
 #if defined(FORCE_STDC) || (defined(__STDC__) && __STDC__ != 0) || \
     defined(__cplusplus)
-# define VSPRINTF_SIZE_T size_t
+# define VSNPRINTF_SIZE_T size_t
 #else
-# define VSPRINTF_SIZE_T long
+# define VSNPRINTF_SIZE_T long
 #endif
 
-char buf[BUFSIZ];
+char buf[BUFSIZ+1];
 
 
 void
-try_this(char *fmt, ...)
-{
-	va_list ap;
-
-	va_start(ap, fmt);
-#if !defined(DONT_HAVE_VSPRINTF)
-	vsprintf(buf, fmt, ap);
-#else
-	sprintf(buf, fmt, ap);
-#endif
-	va_end(ap);
-}
-
-
-void
-try_nthis(char *fmt, VSPRINTF_SIZE_T size, ...)
+try_nthis(char *fmt, VSNPRINTF_SIZE_T size, ...)
 {
 	va_list ap;
 
 	va_start(ap, size);
-#if !defined(DONT_HAVE_VSPRINTF)
+#if !defined(DONT_HAVE_VSNPRINTF)
 	vsnprintf(buf, size, fmt, ap);
 #else
 	snprintf(buf, size, fmt, ap);
@@ -110,36 +91,12 @@ main(void)
 	 */
 	buf[0] = '\0';
 
-	/*
-	 * test variable args and vsprintf/sprintf
-	 */
-	try_this("@%d:%s:%d@", 1, "hi", 2);
-	if (strcmp(buf, "@1:hi:2@") != 0) {
-#if !defined(DONT_HAVE_VSPRINTF)
-	    /* <stdarg.h> with vsprintf() didn't work */
-#else
-	    /* <stdarg.h> with sprintf() simulating vsprintf() didn't work */
-#endif
-	    exit(1);
-	}
-	try_this("%s %d%s%d%d %s",
-	    "Landon Noll 1st coproved that", 2, "^", 21701, -1, "was prime");
-	if (strcmp(buf,
-		   "Landon Noll 1st coproved that 2^21701-1 was prime") != 0) {
-#if !defined(DONT_HAVE_VSPRINTF)
-	    /* <stdarg.h> with vsprintf() didn't work */
-#else
-	    /* <stdarg.h> with sprintf() simulating vsprintf() didn't work */
-#endif
-	    exit(1);
-	}
-
 	/*
 	 * test variable args and vsnprintf/snprintf
 	 */
 	try_nthis("@%d:%s:%d@", sizeof(buf)-1, 1, "hello", 5);
 	if (strcmp(buf, "@1:hello:5@") != 0) {
-#if !defined(DONT_HAVE_VSPRINTF)
+#if !defined(DONT_HAVE_VSNPRINTF)
 	    /* <stdarg.h> with vsnprintf() didn't work */
 #else
 	    /* <stdarg.h> with snprintf() simulating vsnprintf() didn't work */
@@ -150,7 +107,7 @@ main(void)
 	    "Landon Noll 1st proved that", 2, "^", 23209, -1, "was prime");
 	if (strcmp(buf,
 		   "Landon Noll 1st proved that 2^23209-1 was prime") != 0) {
-#if !defined(DONT_HAVE_VSPRINTF)
+#if !defined(DONT_HAVE_VSNPRINTF)
 	    /* <stdarg.h> with vsnprintf() didn't work */
 #else
 	    /* <stdarg.h> with snprintf() simulating vsnprintf() didn't work */
@@ -162,7 +119,7 @@ main(void)
 	 * report the result
 	 */
 	puts("/* what type of variable args do we have? */");
-#if defined(DONT_HAVE_VSPRINTF)
+#if defined(DONT_HAVE_VSNPRINTF)
 	puts("/*");
 	puts(" * SIMULATE_STDARG");
 	puts(" *");
@@ -183,22 +140,21 @@ main(void)
 	puts("#define STDARG /* use <stdarg.h> */");
 	puts("#include <stdarg.h>");
 #endif
-	puts("\n/* should we use vsprintf() and vsnprintf()? */");
-#if !defined(DONT_HAVE_VSPRINTF)
-	puts("#define HAVE_VSPRINTF /* yes */");
+	puts("\n/* should we use vsnprintf() and vsnprintf()? */");
+#if !defined(DONT_HAVE_VSNPRINTF)
+	puts("#define HAVE_VSNPRINTF /* yes */");
 #else
 	puts("/*");
 	puts(" * Hack aleart!!!");
 	puts(" *");
-	puts(" * Systems that do not have vsprintf() need something.  In some");
-	puts(" * cases the sprintf function will deal correctly with the");
-	puts(" * va_alist 3rd arg.  Same gors for a lack of an vsnprintf()");
+	puts(" * Systems that do not have vsnprintf() need something. In some");
+	puts(" * cases the snprintf function will deal correctly with the");
+	puts(" * va_alist 4th arg.  Same gors for a lack of an vsnprintf()");
 	puts(" * function.  In either case we use the #defines below and");
 	puts(" * hope for the best!");
 	puts(" */");
-	puts("#define vsprintf sprintf");
 	puts("#define vsnprintf snprintf");
-	puts("#undef HAVE_VSPRINTF");
+	puts("#undef HAVE_VSNPRINTF");
 #endif
 	/* exit(0); */
 	return 0;
