@@ -17,10 +17,6 @@
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * @(#) $Revision: 30.2 $
- * @(#) $Id: math_error.c,v 30.2 2008/10/24 09:49:20 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/math_error.c,v $
- *
  * Under source code control:	1994/08/03 05:08:22
  * File existed as early as:	1994
  *
@@ -87,7 +83,7 @@ math_error(char *fmt, ...)
 #endif
 	vsnprintf(calc_err_msg, MAXERROR, fmt, ap);
 	va_end(ap);
-	calc_err_msg[MAXERROR] = '\0';
+	calc_err_msg[MAXERROR] = '\0';	/* paranoia */
 
 	/*
 	 * if we should longjmp, so do
