@@ -22,10 +22,6 @@
  * NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR  IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * @(#) $Revision: 30.4 $
- * @(#) $Id: sha1.c,v 30.4 2013/08/11 01:08:32 chongo Exp $
- * @(#) $Source: /usr/local/src/bin/calc/RCS/sha1.c,v $
- *
  * This file is not covered under version 2.1 of the GNU LGPL.
  */
 
@@ -688,7 +684,7 @@ sha1_print(HASH *state)
 		 *	 the last full update or finalization.	Thus it
 		 *	 may NOT be the actual hash value.
 		 */
-		sprintf(buf,
+		snprintf(buf, DEBUG_SIZE,
 			"sha1: 0x%08x%08x%08x%08x%08x data: %d octets",
 			(int)state->h_union.h_sha1.digest[0],
 			(int)state->h_union.h_sha1.digest[1],
@@ -696,6 +692,7 @@ sha1_print(HASH *state)
 			(int)state->h_union.h_sha1.digest[3],
 			(int)state->h_union.h_sha1.digest[4],
 			(int)state->h_union.h_sha1.datalen);
+		buf[DEBUG_SIZE] = '\0';	/* paranoia */
 		math_str(buf);
 	} else {
 		math_str("sha1 hash state");
